Class: Aws::LaunchWizard::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LaunchWizard::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-launchwizard/client.rb,
sig/client.rbs
Overview
An API client for LaunchWizard. To construct a client, you need to configure a :region and :credentials.
client = Aws::LaunchWizard::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateDeploymentResponseSuccess, _DeleteDeploymentResponseSuccess, _GetDeploymentPatternVersionResponseSuccess, _GetDeploymentResponseSuccess, _GetWorkloadDeploymentPatternResponseSuccess, _GetWorkloadResponseSuccess, _ListDeploymentEventsResponseSuccess, _ListDeploymentPatternVersionsResponseSuccess, _ListDeploymentsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkloadDeploymentPatternsResponseSuccess, _ListWorkloadsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDeploymentResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Creates a deployment for the given workload.
-
#delete_deployment(params = {}) ⇒ Types::DeleteDeploymentOutput
Deletes a deployment.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentOutput
Returns information about the deployment.
-
#get_deployment_pattern_version(params = {}) ⇒ Types::GetDeploymentPatternVersionOutput
Returns information about a deployment pattern version.
-
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Returns information about a workload.
-
#get_workload_deployment_pattern(params = {}) ⇒ Types::GetWorkloadDeploymentPatternOutput
Returns details for a given workload and deployment pattern, including the available specifications.
-
#list_deployment_events(params = {}) ⇒ Types::ListDeploymentEventsOutput
Lists the events of a deployment.
-
#list_deployment_pattern_versions(params = {}) ⇒ Types::ListDeploymentPatternVersionsOutput
Lists the deployment pattern versions.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsOutput
Lists the deployments that have been created.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with a specified resource.
-
#list_workload_deployment_patterns(params = {}) ⇒ Types::ListWorkloadDeploymentPatternsOutput
Lists the workload deployment patterns for a given workload name.
-
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Lists the available workload names.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the given resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the given resource.
-
#update_deployment(params = {}) ⇒ Types::UpdateDeploymentOutput
Updates a deployment.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1675 1676 1677 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1675 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1678 1679 1680 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1678 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1648 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LaunchWizard') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-launchwizard' context[:gem_version] = '1.40.0' Seahorse::Client::Request.new(handlers, context) end |
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Creates a deployment for the given workload. Deployments created by
this operation are not available in the Launch Wizard console to use
the Clone deployment action on.
86 |
# File 'sig/client.rbs', line 86
def create_deployment: (
|
#delete_deployment(params = {}) ⇒ Types::DeleteDeploymentOutput
Deletes a deployment.
102 |
# File 'sig/client.rbs', line 102
def delete_deployment: (
|
#get_deployment(params = {}) ⇒ Types::GetDeploymentOutput
Returns information about the deployment.
112 |
# File 'sig/client.rbs', line 112
def get_deployment: (
|
#get_deployment_pattern_version(params = {}) ⇒ Types::GetDeploymentPatternVersionOutput
Returns information about a deployment pattern version.
122 |
# File 'sig/client.rbs', line 122
def get_deployment_pattern_version: (
|
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Returns information about a workload.
134 |
# File 'sig/client.rbs', line 134
def get_workload: (
|
#get_workload_deployment_pattern(params = {}) ⇒ Types::GetWorkloadDeploymentPatternOutput
Returns details for a given workload and deployment pattern, including the available specifications. You can use the ListWorkloads operation to discover the available workload names and the ListWorkloadDeploymentPatterns operation to discover the available deployment pattern names of a given workload.
144 |
# File 'sig/client.rbs', line 144
def get_workload_deployment_pattern: (
|
#list_deployment_events(params = {}) ⇒ Types::ListDeploymentEventsOutput
Lists the events of a deployment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
156 |
# File 'sig/client.rbs', line 156
def list_deployment_events: (
|
#list_deployment_pattern_versions(params = {}) ⇒ Types::ListDeploymentPatternVersionsOutput
Lists the deployment pattern versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
169 |
# File 'sig/client.rbs', line 169
def list_deployment_pattern_versions: (
|
#list_deployments(params = {}) ⇒ Types::ListDeploymentsOutput
Lists the deployments that have been created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
189 |
# File 'sig/client.rbs', line 189
def list_deployments: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with a specified resource.
206 |
# File 'sig/client.rbs', line 206
def list_tags_for_resource: (
|
#list_workload_deployment_patterns(params = {}) ⇒ Types::ListWorkloadDeploymentPatternsOutput
Lists the workload deployment patterns for a given workload name. You can use the ListWorkloads operation to discover the available workload names.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
217 |
# File 'sig/client.rbs', line 217
def list_workload_deployment_patterns: (
|
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Lists the available workload names. You can use the ListWorkloadDeploymentPatterns operation to discover the available deployment patterns for a given workload.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
230 |
# File 'sig/client.rbs', line 230
def list_workloads: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the given resource.
240 |
# File 'sig/client.rbs', line 240
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the given resource.
250 |
# File 'sig/client.rbs', line 250
def untag_resource: (
|
#update_deployment(params = {}) ⇒ Types::UpdateDeploymentOutput
Updates a deployment.
261 |
# File 'sig/client.rbs', line 261
def update_deployment: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1668 1669 1670 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1668 def waiter_names [] end |