Class: Aws::LaunchWizard::Types::UpdateDeploymentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::LaunchWizard::Types::UpdateDeploymentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-launchwizard/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:specifications]
Instance Attribute Summary collapse
-
#deployment_id ⇒ String
The ID of the deployment.
-
#deployment_pattern_version_name ⇒ String
The name of the deployment pattern version.
-
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action, without actually making the request, and provides an error response.
-
#force ⇒ Boolean
Forces the update even if validation warnings are present.
-
#specifications ⇒ Hash<String,String>
The settings specified for the deployment.
-
#workload_version_name ⇒ String
The name of the workload version.
Instance Attribute Details
#deployment_id ⇒ String
The ID of the deployment.
987 988 989 990 991 992 993 994 995 996 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 987 class UpdateDeploymentInput < Struct.new( :deployment_id, :specifications, :workload_version_name, :deployment_pattern_version_name, :dry_run, :force) SENSITIVE = [:specifications] include Aws::Structure end |
#deployment_pattern_version_name ⇒ String
The name of the deployment pattern version.
987 988 989 990 991 992 993 994 995 996 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 987 class UpdateDeploymentInput < Struct.new( :deployment_id, :specifications, :workload_version_name, :deployment_pattern_version_name, :dry_run, :force) SENSITIVE = [:specifications] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response.
If you have the required permissions, the error response is
DryRunOperation. Otherwise, it is UnauthorizedOperation.
987 988 989 990 991 992 993 994 995 996 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 987 class UpdateDeploymentInput < Struct.new( :deployment_id, :specifications, :workload_version_name, :deployment_pattern_version_name, :dry_run, :force) SENSITIVE = [:specifications] include Aws::Structure end |
#force ⇒ Boolean
Forces the update even if validation warnings are present.
987 988 989 990 991 992 993 994 995 996 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 987 class UpdateDeploymentInput < Struct.new( :deployment_id, :specifications, :workload_version_name, :deployment_pattern_version_name, :dry_run, :force) SENSITIVE = [:specifications] include Aws::Structure end |
#specifications ⇒ Hash<String,String>
The settings specified for the deployment. These settings define how
to deploy and configure your resources created by the deployment.
For more information about the specifications required for creating
a deployment for a SAP workload, see SAP deployment
specifications. To retrieve the specifications required to
create a deployment for other workloads, use the
GetWorkloadDeploymentPattern operation.
987 988 989 990 991 992 993 994 995 996 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 987 class UpdateDeploymentInput < Struct.new( :deployment_id, :specifications, :workload_version_name, :deployment_pattern_version_name, :dry_run, :force) SENSITIVE = [:specifications] include Aws::Structure end |
#workload_version_name ⇒ String
The name of the workload version.
987 988 989 990 991 992 993 994 995 996 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 987 class UpdateDeploymentInput < Struct.new( :deployment_id, :specifications, :workload_version_name, :deployment_pattern_version_name, :dry_run, :force) SENSITIVE = [:specifications] include Aws::Structure end |