Class: Aws::LaunchWizard::Types::WorkloadData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-launchwizard/types.rb

Overview

Describes a workload.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_constraintsArray<Types::AccountConstraint>

Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern. Within a single list the semantics are OR: an account satisfies the list if it satisfies any entry. Workload-level and pattern-level lists combine with AND at deployment time. An absent or empty list at this level means no constraint at this level.

Returns:



1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of a workload.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of a workload.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#documentation_urlString

The URL of a workload document.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#icon_urlString

The URL of a workload icon.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of a workload.

You can list deployments in the DISABLED status.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The message about a workload's status.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#workload_nameString

The name of the workload.

Returns:

  • (String)


1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067

class WorkloadData < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints,
  :description,
  :documentation_url,
  :icon_url,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end