Class: Aws::LaunchWizard::Types::WorkloadDataSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-launchwizard/types.rb

Overview

Describes workload data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_constraintsArray<Types::AccountConstraint>

Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern. Within a single list the semantics are OR: an account satisfies the list if it satisfies any entry. Workload-level and pattern-level lists combine with AND at deployment time. An absent or empty list at this level means no constraint at this level.

Returns:



1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105

class WorkloadDataSummary < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the workload data.

Returns:

  • (String)


1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105

class WorkloadDataSummary < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the workload.

Returns:

  • (String)


1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105

class WorkloadDataSummary < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints)
  SENSITIVE = []
  include Aws::Structure
end

#workload_nameString

The name of the workload.

Returns:

  • (String)


1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105

class WorkloadDataSummary < Struct.new(
  :workload_name,
  :display_name,
  :status,
  :account_constraints)
  SENSITIVE = []
  include Aws::Structure
end