Class: Aws::LaunchWizard::Types::WorkloadDeploymentPatternData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-launchwizard/types.rb

Overview

The data that details a workload deployment pattern.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_constraintsArray<Types::AccountConstraint>

Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern. Within a single list the semantics are OR: an account satisfies the list if it satisfies any entry. Workload-level and pattern-level lists combine with AND at deployment time. An absent or empty list at this level means no constraint at this level.

Returns:



1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_pattern_nameString

The name of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_pattern_version_nameString

The version name of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#specificationsArray<Types::DeploymentSpecificationsField>

The settings specified for the deployment. These settings define how to deploy and configure your resources created by the deployment. For more information about the specifications required for creating a deployment for a SAP workload, see SAP deployment specifications. To retrieve the specifications required to create a deployment for other workloads, use the GetWorkloadDeploymentPattern operation.



1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The status message of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#workload_nameString

The workload name of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#workload_version_nameString

The workload version name of the deployment pattern.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
# File 'lib/aws-sdk-launchwizard/types.rb', line 1174

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :account_constraints,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end