Class: Aws::LaunchWizard::Types::WorkloadDeploymentPatternDataSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LaunchWizard::Types::WorkloadDeploymentPatternDataSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-launchwizard/types.rb
Overview
Describes a workload deployment pattern.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_constraints ⇒ Array<Types::AccountConstraint>
Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern.
-
#deployment_pattern_name ⇒ String
The name of a workload deployment pattern.
-
#deployment_pattern_version_name ⇒ String
The version name of a workload deployment pattern.
-
#description ⇒ String
The description of a workload deployment pattern.
-
#display_name ⇒ String
The display name of a workload deployment pattern.
-
#status ⇒ String
The status of a workload deployment pattern.
-
#status_message ⇒ String
A message about a workload deployment pattern's status.
-
#workload_name ⇒ String
The name of the workload.
-
#workload_version_name ⇒ String
The name of the workload deployment pattern version.
Instance Attribute Details
#account_constraints ⇒ Array<Types::AccountConstraint>
Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern. Within a single list the semantics are OR: an account satisfies the list if it satisfies any entry. Workload-level and pattern-level lists combine with AND at deployment time. An absent or empty list at this level means no constraint at this level.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#deployment_pattern_name ⇒ String
The name of a workload deployment pattern.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#deployment_pattern_version_name ⇒ String
The version name of a workload deployment pattern.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of a workload deployment pattern.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of a workload deployment pattern.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a workload deployment pattern.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message about a workload deployment pattern's status.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#workload_name ⇒ String
The name of the workload.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#workload_version_name ⇒ String
The name of the workload deployment pattern version.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1234 class WorkloadDeploymentPatternDataSummary < Struct.new( :workload_name, :deployment_pattern_name, :workload_version_name, :deployment_pattern_version_name, :display_name, :description, :status, :status_message, :account_constraints) SENSITIVE = [] include Aws::Structure end |