Class: Aws::LaunchWizard::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LaunchWizard::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-launchwizard/client.rb
Overview
An API client for LaunchWizard. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::LaunchWizard::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Creates a deployment for the given workload.
-
#delete_deployment(params = {}) ⇒ Types::DeleteDeploymentOutput
Deletes a deployment.
-
#get_deployment(params = {}) ⇒ Types::GetDeploymentOutput
Returns information about the deployment.
-
#get_deployment_pattern_version(params = {}) ⇒ Types::GetDeploymentPatternVersionOutput
Returns information about a deployment pattern version.
-
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Returns information about a workload.
-
#get_workload_deployment_pattern(params = {}) ⇒ Types::GetWorkloadDeploymentPatternOutput
Returns details for a given workload and deployment pattern, including the available specifications.
-
#list_deployment_events(params = {}) ⇒ Types::ListDeploymentEventsOutput
Lists the events of a deployment.
-
#list_deployment_pattern_versions(params = {}) ⇒ Types::ListDeploymentPatternVersionsOutput
Lists the deployment pattern versions.
-
#list_deployments(params = {}) ⇒ Types::ListDeploymentsOutput
Lists the deployments that have been created.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with a specified resource.
-
#list_workload_deployment_patterns(params = {}) ⇒ Types::ListWorkloadDeploymentPatternsOutput
Lists the workload deployment patterns for a given workload name.
-
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Lists the available workload names.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the given resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the given resource.
-
#update_deployment(params = {}) ⇒ Types::UpdateDeploymentOutput
Updates a deployment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1675 1676 1677 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1675 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1678 1679 1680 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1678 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1648 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LaunchWizard') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-launchwizard' context[:gem_version] = '1.38.0' Seahorse::Client::Request.new(handlers, context) end |
#create_deployment(params = {}) ⇒ Types::CreateDeploymentOutput
Creates a deployment for the given workload. Deployments created by this operation are not available in the Launch Wizard console to use the ‘Clone deployment` action on.
610 611 612 613 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 610 def create_deployment(params = {}, = {}) req = build_request(:create_deployment, params) req.send_request() end |
#delete_deployment(params = {}) ⇒ Types::DeleteDeploymentOutput
Deletes a deployment.
653 654 655 656 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 653 def delete_deployment(params = {}, = {}) req = build_request(:delete_deployment, params) req.send_request() end |
#get_deployment(params = {}) ⇒ Types::GetDeploymentOutput
Returns information about the deployment.
729 730 731 732 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 729 def get_deployment(params = {}, = {}) req = build_request(:get_deployment, params) req.send_request() end |
#get_deployment_pattern_version(params = {}) ⇒ Types::GetDeploymentPatternVersionOutput
Returns information about a deployment pattern version.
780 781 782 783 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 780 def get_deployment_pattern_version(params = {}, = {}) req = build_request(:get_deployment_pattern_version, params) req.send_request() end |
#get_workload(params = {}) ⇒ Types::GetWorkloadOutput
Returns information about a workload.
833 834 835 836 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 833 def get_workload(params = {}, = {}) req = build_request(:get_workload, params) req.send_request() end |
#get_workload_deployment_pattern(params = {}) ⇒ Types::GetWorkloadDeploymentPatternOutput
Returns details for a given workload and deployment pattern, including the available specifications. You can use the [ListWorkloads] operation to discover the available workload names and the
- ListWorkloadDeploymentPatterns][2
-
operation to discover the
available deployment pattern names of a given workload.
[1]: docs.aws.amazon.com/launchwizard/latest/APIReference/API_ListWorkloads.html [2]: docs.aws.amazon.com/launchwizard/latest/APIReference/API_ListWorkloadDeploymentPatterns.html
928 929 930 931 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 928 def get_workload_deployment_pattern(params = {}, = {}) req = build_request(:get_workload_deployment_pattern, params) req.send_request() end |
#list_deployment_events(params = {}) ⇒ Types::ListDeploymentEventsOutput
Lists the events of a deployment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1003 1004 1005 1006 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1003 def list_deployment_events(params = {}, = {}) req = build_request(:list_deployment_events, params) req.send_request() end |
#list_deployment_pattern_versions(params = {}) ⇒ Types::ListDeploymentPatternVersionsOutput
Lists the deployment pattern versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1127 1128 1129 1130 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1127 def list_deployment_pattern_versions(params = {}, = {}) req = build_request(:list_deployment_pattern_versions, params) req.send_request() end |
#list_deployments(params = {}) ⇒ Types::ListDeploymentsOutput
Lists the deployments that have been created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1216 1217 1218 1219 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1216 def list_deployments(params = {}, = {}) req = build_request(:list_deployments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with a specified resource.
1260 1261 1262 1263 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1260 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workload_deployment_patterns(params = {}) ⇒ Types::ListWorkloadDeploymentPatternsOutput
Lists the workload deployment patterns for a given workload name. You can use the [ListWorkloads] operation to discover the available workload names.
[1]: docs.aws.amazon.com/launchwizard/latest/APIReference/API_ListWorkloads.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1346 1347 1348 1349 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1346 def list_workload_deployment_patterns(params = {}, = {}) req = build_request(:list_workload_deployment_patterns, params) req.send_request() end |
#list_workloads(params = {}) ⇒ Types::ListWorkloadsOutput
Lists the available workload names. You can use the
- ListWorkloadDeploymentPatterns][1
-
operation to discover the
available deployment patterns for a given workload.
[1]: docs.aws.amazon.com/launchwizard/latest/APIReference/API_ListWorkloadDeploymentPatterns.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1416 1417 1418 1419 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1416 def list_workloads(params = {}, = {}) req = build_request(:list_workloads, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the given resource.
1459 1460 1461 1462 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1459 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the given resource.
1500 1501 1502 1503 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1500 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_deployment(params = {}) ⇒ Types::UpdateDeploymentOutput
Updates a deployment.
1639 1640 1641 1642 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1639 def update_deployment(params = {}, = {}) req = build_request(:update_deployment, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1668 1669 1670 |
# File 'lib/aws-sdk-launchwizard/client.rb', line 1668 def waiter_names [] end |