Class: Aws::LaunchWizard::Types::AccountConstraint
- Inherits:
-
Struct
- Object
- Struct
- Aws::LaunchWizard::Types::AccountConstraint
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-launchwizard/types.rb
Overview
AccountConstraint is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AccountConstraint corresponding to the set member.
A constraint on which AWS account a deployment can be initiated from. Specify one of the supported constraint types.
Defined Under Namespace
Classes: DelegatedAdmin, ManagementAccount, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delegated_admin ⇒ Types::DelegatedAdminConstraint
The deployment must be initiated from a delegated administrator account for the specified service principal.
-
#management_account ⇒ Types::ManagementAccountConstraint
The deployment must be initiated from the AWS Organizations management account.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#delegated_admin ⇒ Types::DelegatedAdminConstraint
The deployment must be initiated from a delegated administrator account for the specified service principal.
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 30 class AccountConstraint < Struct.new( :management_account, :delegated_admin, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ManagementAccount < AccountConstraint; end class DelegatedAdmin < AccountConstraint; end class Unknown < AccountConstraint; end end |
#management_account ⇒ Types::ManagementAccountConstraint
The deployment must be initiated from the AWS Organizations management account.
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 30 class AccountConstraint < Struct.new( :management_account, :delegated_admin, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ManagementAccount < AccountConstraint; end class DelegatedAdmin < AccountConstraint; end class Unknown < AccountConstraint; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
30 31 32 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 30 def unknown @unknown end |