Class: Aws::LaunchWizard::Types::DelegatedAdminConstraint
- Inherits:
-
Struct
- Object
- Struct
- Aws::LaunchWizard::Types::DelegatedAdminConstraint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-launchwizard/types.rb
Overview
The deployment must be initiated from a delegated administrator account for the specified service principal.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_principal ⇒ String
The service principal for which the account must be a delegated administrator.
Instance Attribute Details
#service_principal ⇒ String
The service principal for which the account must be a delegated
administrator. For example,
stacksets.cloudformation.amazonaws.com.
128 129 130 131 132 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 128 class DelegatedAdminConstraint < Struct.new( :service_principal) SENSITIVE = [] include Aws::Structure end |