Class: Aws::LaunchWizard::Types::WorkloadData
- Inherits:
-
Struct
- Object
- Struct
- Aws::LaunchWizard::Types::WorkloadData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-launchwizard/types.rb
Overview
Describes a workload.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_constraints ⇒ Array<Types::AccountConstraint>
Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern.
-
#description ⇒ String
The description of a workload.
-
#display_name ⇒ String
The display name of a workload.
-
#documentation_url ⇒ String
The URL of a workload document.
-
#icon_url ⇒ String
The URL of a workload icon.
-
#status ⇒ String
The status of a workload.
-
#status_message ⇒ String
The message about a workload's status.
-
#workload_name ⇒ String
The name of the workload.
Instance Attribute Details
#account_constraints ⇒ Array<Types::AccountConstraint>
Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern. Within a single list the semantics are OR: an account satisfies the list if it satisfies any entry. Workload-level and pattern-level lists combine with AND at deployment time. An absent or empty list at this level means no constraint at this level.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of a workload.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of a workload.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#documentation_url ⇒ String
The URL of a workload document.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#icon_url ⇒ String
The URL of a workload icon.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a workload.
You can list deployments in the DISABLED status.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
The message about a workload's status.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |
#workload_name ⇒ String
The name of the workload.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1067 class WorkloadData < Struct.new( :workload_name, :display_name, :status, :account_constraints, :description, :documentation_url, :icon_url, :status_message) SENSITIVE = [] include Aws::Structure end |