Class: Aws::LaunchWizard::Types::WorkloadDataSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LaunchWizard::Types::WorkloadDataSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-launchwizard/types.rb
Overview
Describes workload data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_constraints ⇒ Array<Types::AccountConstraint>
Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern.
-
#display_name ⇒ String
The display name of the workload data.
-
#status ⇒ String
The status of the workload.
-
#workload_name ⇒ String
The name of the workload.
Instance Attribute Details
#account_constraints ⇒ Array<Types::AccountConstraint>
Optional list of constraints describing what kind of AWS account is allowed to deploy this workload or deployment pattern. Within a single list the semantics are OR: an account satisfies the list if it satisfies any entry. Workload-level and pattern-level lists combine with AND at deployment time. An absent or empty list at this level means no constraint at this level.
1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105 class WorkloadDataSummary < Struct.new( :workload_name, :display_name, :status, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the workload data.
1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105 class WorkloadDataSummary < Struct.new( :workload_name, :display_name, :status, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the workload.
1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105 class WorkloadDataSummary < Struct.new( :workload_name, :display_name, :status, :account_constraints) SENSITIVE = [] include Aws::Structure end |
#workload_name ⇒ String
The name of the workload.
1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/aws-sdk-launchwizard/types.rb', line 1105 class WorkloadDataSummary < Struct.new( :workload_name, :display_name, :status, :account_constraints) SENSITIVE = [] include Aws::Structure end |