Class: Aws::LaunchWizard::Types::WorkloadDeploymentPatternData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-launchwizard/types.rb

Overview

The data that details a workload deployment pattern.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_pattern_nameString

The name of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_pattern_version_nameString

The version name of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#specificationsArray<Types::DeploymentSpecificationsField>

The settings specified for the deployment. These settings define how to deploy and configure your resources created by the deployment. For more information about the specifications required for creating a deployment for a SAP workload, see [SAP deployment specifications]. To retrieve the specifications required to create a deployment for other workloads, use the [ ‘GetWorkloadDeploymentPattern` ][2] operation.

[1]: docs.aws.amazon.com/launchwizard/latest/APIReference/launch-wizard-specifications-sap.html [2]: docs.aws.amazon.com/launchwizard/latest/APIReference/API_GetWorkloadDeploymentPattern.html



1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The status message of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#workload_nameString

The workload name of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end

#workload_version_nameString

The workload version name of the deployment pattern.

Returns:

  • (String)


1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/aws-sdk-launchwizard/types.rb', line 1084

class WorkloadDeploymentPatternData < Struct.new(
  :workload_name,
  :deployment_pattern_name,
  :workload_version_name,
  :deployment_pattern_version_name,
  :display_name,
  :description,
  :status,
  :status_message,
  :specifications)
  SENSITIVE = []
  include Aws::Structure
end